@@ -1,19 +1,20 @@
+import os
 import time
+import base64
 import asyncio
 import hashlib
-import os
-import base64
 
-import requests
 import aiohttp
+import requests
+from requests.adapters import HTTPAdapter
 
 from python3_anticaptcha import (
-    create_task_url,
+    ReadError,
+    ParamError,
     app_key,
+    create_task_url,
     get_sync_result,
     get_async_result,
-    ParamError,
-    ReadError,
 )
 
 SAVE_FORMATS = ("const", "temp")
@@ -72,6 +73,13 @@ class ImageToTextTask:
         # если всё ок - идём дальше
         self.result_payload = {"clientKey": anticaptcha_key}
 
+        # создаём сессию
+        self.session = requests.Session()
+        # выставляем кол-во попыток подключения к серверу при ошибке
+        self.session.mount("http://", HTTPAdapter(max_retries=5))
+        self.session.mount("https://", HTTPAdapter(max_retries=5))
+        self.session.verify = False
+
         # Если переданы ещё параметры - вносим их в payload
         if kwargs:
             for key in kwargs:
@@ -94,7 +102,7 @@ class ImageToTextTask:
         self.task_payload["task"].update({"body": base64.b64encode(content).decode("utf-8")})
         # Отправляем на рукапча изображение капчи и другие парметры,
         # в результате получаем JSON ответ с номером решаемой капчи и получая ответ - извлекаем номер
-        captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+        captcha_id = self.session.post(create_task_url, json=self.task_payload).json()
         return captcha_id
 
     def __image_const_saver(self, content: bytes):
@@ -120,7 +128,7 @@ class ImageToTextTask:
             )
             # Отправляем на антикапча изображение капчи и другие парметры,
             # в результате получаем JSON ответ содержащий номер решаемой капчи
-            captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+            captcha_id = self.session.post(create_task_url, json=self.task_payload).json()
 
         # удаляем файл капчи
         os.remove(os.path.join(img_path, "im-{0}.png".format(image_hash)))
@@ -150,7 +158,7 @@ class ImageToTextTask:
                 )
             # Отправляем на антикапча изображение капчи и другие парметры,
             # в результате получаем JSON ответ содержащий номер решаемой капчи
-            captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+            captcha_id = self.session.post(create_task_url, json=self.task_payload).json()
         except (IOError, FileNotFoundError) as err:
             raise ReadError(err)
 
@@ -177,7 +185,7 @@ class ImageToTextTask:
         elif captcha_base64:
             captcha_id = self.__read_captcha_image_file(captcha_base64, content_type="base64")
         elif captcha_link:
-            content = requests.get(captcha_link, **kwargs).content
+            content = self.session.get(captcha_link, **kwargs).content
             # согласно значения переданного параметра выбираем функцию для сохранения изображения
             if self.save_format == SAVE_FORMATS[0]:
                 captcha_id = self.__image_const_saver(content)
@@ -352,7 +360,9 @@ class aioImageToTextTask:
                 )
             # Отправляем на антикапча изображение капчи и другие парметры,
             # в результате получаем JSON ответ содержащий номер решаемой капчи
-            captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+            async with aiohttp.ClientSession() as session:
+                async with session.post(create_task_url, json=self.task_payload) as resp:
+                    captcha_id = await resp.json()
         except (IOError, FileNotFoundError) as err:
             raise ReadError(err)
 
