@@ -1,24 +1,15 @@
 import time
 import asyncio
 
-import requests
 import aiohttp
+import requests
 
-from python3_anticaptcha import (
-    create_task_url,
-    app_key,
-    get_sync_result,
-    get_async_result,
-)
+from python3_anticaptcha import app_key, create_task_url, get_sync_result, get_async_result
 
 
 class NoCaptchaTaskProxyless:
     def __init__(
-        self,
-        anticaptcha_key: str,
-        sleep_time: int = 5,
-        callbackUrl: str = None,
-        **kwargs,
+        self, anticaptcha_key: str, sleep_time: int = 5, callbackUrl: str = None, **kwargs
     ):
         """
 		Модуль отвечает за решение ReCaptcha без прокси
@@ -28,9 +19,7 @@ class NoCaptchaTaskProxyless:
 		:param kwargs: Другие необязательные параметры из документации
 		"""
         if sleep_time < 5:
-            raise ValueError(
-                f"Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}"
-            )
+            raise ValueError(f"Param `sleep_time` must be greater than 5. U set - {sleep_time}")
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
@@ -60,7 +49,7 @@ class NoCaptchaTaskProxyless:
         return True
 
     # Работа с капчёй
-    def captcha_handler(self, websiteURL, websiteKey, **kwargs):
+    def captcha_handler(self, websiteURL, websiteKey, **kwargs) -> dict:
         """
 		Метод решения ReCaptcha
 		:param websiteURL: Ссылка на страницу с капчёй
@@ -69,13 +58,11 @@ class NoCaptchaTaskProxyless:
 		"""
 
         # вставляем в пайлоад адрес страницы и ключ-индентификатор рекапчи
-        self.task_payload["task"].update(
-            {"websiteURL": websiteURL, "websiteKey": websiteKey}
-        )
+        self.task_payload["task"].update({"websiteURL": websiteURL, "websiteKey": websiteKey})
         # Отправляем на антикапчу пайлоад
         # в результате получаем JSON ответ содержащий номер решаемой капчи
         captcha_id = requests.post(
-            create_task_url, json=self.task_payload, **kwargs
+            create_task_url, json=self.task_payload, verify=False, **kwargs
         ).json()
 
         # Проверка статуса создания задачи, если создано без ошибок - извлекаем ID задачи, иначе возвращаем ответ сервера
@@ -92,18 +79,12 @@ class NoCaptchaTaskProxyless:
         else:
             # Ожидаем решения капчи
             time.sleep(self.sleep_time)
-            return get_sync_result(
-                result_payload=self.result_payload, sleep_time=self.sleep_time
-            )
+            return get_sync_result(result_payload=self.result_payload, sleep_time=self.sleep_time)
 
 
 class aioNoCaptchaTaskProxyless:
     def __init__(
-        self,
-        anticaptcha_key: str,
-        sleep_time: int = 5,
-        callbackUrl: str = None,
-        **kwargs,
+        self, anticaptcha_key: str, sleep_time: int = 5, callbackUrl: str = None, **kwargs
     ):
         """
 		Модуль отвечает за решение ReCaptcha без прокси
@@ -113,9 +94,7 @@ class aioNoCaptchaTaskProxyless:
 		:param kwargs: Другие необязательные параметры из документации
 		"""
         if sleep_time < 5:
-            raise ValueError(
-                f"Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}"
-            )
+            raise ValueError(f"Param `sleep_time` must be greater than 5. U set - {sleep_time}")
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
@@ -146,7 +125,7 @@ class aioNoCaptchaTaskProxyless:
         return True
 
     # Работа с капчёй
-    async def captcha_handler(self, websiteURL, websiteKey):
+    async def captcha_handler(self, websiteURL, websiteKey) -> dict:
         """
 		Метод решения ReCaptcha
 		:param websiteURL: Ссылка на страницу с капчёй
@@ -155,9 +134,7 @@ class aioNoCaptchaTaskProxyless:
 		"""
 
         # вставляем в пайлоад адрес страницы и ключ-индентификатор рекапчи
-        self.task_payload["task"].update(
-            {"websiteURL": websiteURL, "websiteKey": websiteKey}
-        )
+        self.task_payload["task"].update({"websiteURL": websiteURL, "websiteKey": websiteKey})
         # Отправляем на антикапчу пайлоад
         # в результате получаем JSON ответ содержащий номер решаемой капчи
         async with aiohttp.ClientSession() as session:
